Class: Bucketize::HourValue
- Inherits:
-
Object
- Object
- Bucketize::HourValue
- Defined in:
- lib/ce-bucketize/model/hour_value.rb
Overview
The consumption value for a given hour.
Author: ahmed.seddiq Version: 1.0
Instance Attribute Summary collapse
-
#hour_start ⇒ Object
A Time object represents the start of the hour in the local time of the consumer.
-
#value ⇒ Object
The consumption value for this hour.
Instance Method Summary collapse
-
#initialize(hour_start, value) ⇒ HourValue
constructor
A new instance of HourValue.
Constructor Details
#initialize(hour_start, value) ⇒ HourValue
Returns a new instance of HourValue.
16 17 18 19 |
# File 'lib/ce-bucketize/model/hour_value.rb', line 16 def initialize(hour_start, value) @hour_start = hour_start @value = value end |
Instance Attribute Details
#hour_start ⇒ Object
A Time object represents the start of the hour in the local time of the consumer.
11 12 13 |
# File 'lib/ce-bucketize/model/hour_value.rb', line 11 def hour_start @hour_start end |
#value ⇒ Object
The consumption value for this hour.
14 15 16 |
# File 'lib/ce-bucketize/model/hour_value.rb', line 14 def value @value end |